package com.ruoyi.model.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.cyl.h5.pojo.vo.H5OrderVO;
import com.ruoyi.model.domain.AppletOrderDateFrequency;
import com.ruoyi.model.domain.AppletOrderItemDateLog;

/**
 * 日订单Service接口
 * 
 * @author daixiande
 */
public interface IAppletOrderDateFrequencyService extends IService<AppletOrderDateFrequency> {
    /**
     * 查询日订单
     * 
     * @param id 日订单主键
     * @return 日订单
     */
    AppletOrderDateFrequency selectAppletOrderDateFrequencyById(Long id);

    /**
     * 查询日订单列表
     * 
     * @param appletOrderDateFrequency 日订单
     * @return 日订单集合
     */
    List<AppletOrderDateFrequency> selectAppletOrderDateFrequencyList(AppletOrderDateFrequency appletOrderDateFrequency);

    /**
     * 新增日订单
     * 
     * @param appletOrderDateFrequency 日订单
     * @return 结果
     */
    int insertAppletOrderDateFrequency(AppletOrderDateFrequency appletOrderDateFrequency);

    /**
     * 修改日订单
     * 
     * @param appletOrderDateFrequency 日订单
     * @return 结果
     */
    int updateAppletOrderDateFrequency(AppletOrderDateFrequency appletOrderDateFrequency);

    /**
     * 批量删除日订单
     * 
     * @param ids 需要删除的日订单主键集合
     * @return 结果
     */
    int deleteAppletOrderDateFrequencyByIds(Long[] ids);



    void buildPetData(AppletOrderDateFrequency frequency);

    /**
     * 删除日订单信息
     * 
     * @param id 日订单主键
     * @return 结果
     */
    int deleteAppletOrderDateFrequencyById(Long id);

    /**
     * 接单生成日订单
     * @param h5OrderVO 下单端订单信息
     * @param masterId 伴宠师ID
     */
    void aceptOrdersGenerateDayOrdersByOrderVO(H5OrderVO h5OrderVO, Long masterId);

    void buildUserData(AppletOrderDateFrequency frequency);

    int check(AppletOrderItemDateLog log);
}
